@@ -26,12 +26,14 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <time.h>
 
 #include "font.h"
 
 #include "args.h"
 #include "common.h"
-#include "config.h"
+#include <config.h>
+#include "vorconfig.h"
 #include "dust.h"
 #include "file.h"
 #include "float.h"
@@ -136,6 +138,18 @@ extern int optind, opterr, optopt;
 
 // ************************************* FUNCS
 
+#ifdef nanosleep
+void
+tiny_sleep() {
+	struct timespec t;
+	t.tv_sec = 0;
+	t.tv_nsec = 1;
+	nanosleep(&t, 0);
+}
+#else
+#define tiny_sleep()
+#endif
+
 void
 init_engine_dots() {
 	int i;
@@ -521,7 +535,7 @@ draw_title_page(void)
 	x = (XSIZE-font_width(text))/2 + cos(fadetimer/4.5)*10;
 	font_write(x,YSIZE-100 + cos(fadetimer/3)*5,text);
 
-	text = "Version " VERSION;
+	text = "Version " PACKAGE_VERSION;
 	x = (XSIZE-font_width(text))/2 + sin(fadetimer/4.5)*10;
 	font_write(x,YSIZE-50 + sin(fadetimer/2)*5,text);
 }
@@ -835,6 +849,8 @@ gameloop() {
 			state = HIGH_SCORE_DISPLAY;
 			state_timeout = 400;
 		}
+
+		tiny_sleep();
 	}
 }
 
