@@ -25,7 +25,7 @@
 #include "font.h"
 
 #include "common.h"
-#include "config.h"
+#include "vorconfig.h"
 #include "file.h"
 #include "globals.h"
 #include "score.h"
